@@ -3,9 +3,11 @@
 
 __author__ = 'Markus Beuckelmann'
 __author_email__ = 'email@markus-beuckelmann.de'
-__version__ = '0.1.2'
+__version__ = '0.2.0'
 
 __all__ = ['de', 'en', 'nl', 'it', 'es', 'fr', 'audiosamples', 'textsamples', 'images']
 
-DEBUG = False
 VERSION = __version__
+
+import lltk.config as config
+config['version'] = __version__
\ No newline at end of file
