@@ -1,7 +1,7 @@
 #!/usr/bin/python
 # -*- coding: UTF-8 -*-
 
-from ..helpers import download, play
+from lltk.helpers import download, play
 
 from google import google
 from forvo import forvo
