@@ -1,5 +1,5 @@
 #!/usr/bin/python
 # -*- coding: UTF-8 -*-
 
-from ..helpers import download
+from lltk.helpers import download
 from google import google
